@@ -5,11 +5,7 @@ Ambisonics
 """
 
 import numpy as np
-try:
-    from scipy import math
-    factorial = math.factorial
-except AttributeError:
-    from scipy.misc import factorial
+import scipy.special
 
 
 def acn(order=1):
@@ -52,7 +48,7 @@ def sn3d(m, n):
     n = np.atleast_1d(n)
 
     d = np.logical_not(m.astype(bool))
-    out = np.sqrt((2.0 - d) / (4.0 * np.pi) * factorial(n - np.abs(m)) / factorial(n + np.abs(m)))
+    out = np.sqrt((2.0 - d) / (4.0 * np.pi) * scipy.special.factorial(n - np.abs(m)) / scipy.special.factorial.factorial(n + np.abs(m)))
     return out
 
 
